This file is part of aiootp, an asynchronous pseudo one-time pad based crypto and anonymity library.

Licensed under the AGPLv3: https://www.gnu.org/licenses/agpl-3.0.html

Copyright

-  © 2019-2021 Gonzo Investigative Journalism Agency, LLC
-  © 2019-2023 Richard Machado <rmlibre@riseup.net>

All rights reserved.




Description
===========

This file is placed in the default directory for transparently encrypted / decrypted database files. Read the package's README.rst for a small guide for understanding how to use them properly & what they offer.


    
     
     